bayespy.inference.vmp.nodes.constant.Constant.set_value
=======================================================

.. currentmodule:: bayespy.inference.vmp.nodes.constant

.. automethod:: Constant.set_value